SystemOrganization addCategory: #RPSS!

TestCase subclass: #RPSS_UserCollectionTest
	instanceVariableNames: 'collection user user2 user3'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RPSS'!

!RPSS_UserCollectionTest methodsFor: 'as yet unclassified' stamp: 'GeoffreyJacquet 10/12/2011 20:31'!
setUp
collection := RPSS_UserCollection new.
user := RPSS_User new.
user2 := RPSS_User new.
user 
	email: 'test1@mail.be';
	password: 'testest';
	isToVerify: false;
	emailVerified: true.
user2 
	email: 'test2@mail.be';
	password: 't2st2st';
	isToVerify: false;
	emailVerified: true.
collection 
	addUser: user;
	addUser: user2.! !

!RPSS_UserCollectionTest methodsFor: 'as yet unclassified' stamp: 'GeoffreyJacquet 10/12/2011 20:31'!
testSelect
	self assert: (collection usersToApprove isEmpty).
	user3 := RPSS_User new.
	user3 
		email: 'test3@mail.be';
		password: 'testest';
		isToVerify: true;
		emailVerified: true.
	collection addUser: user3.
	self deny: (collection usersToApprove isEmpty).! !

Object subclass: #RPSS_UserCollection
	instanceVariableNames: 'collection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RPSS'!

RPSS_UserCollection class
	instanceVariableNames: 'uniqueInstance'!

!RPSS_UserCollection commentStamp: 'BogatchevOleg 10/12/2011 18:00' prior: 0!
I'm RPSS UserCollection, I store user data, as an IdentityDictionary, and I use only letters symbols of user emails as keys

Instance Variables:
	collection	<(Collection of: RPSS_User)>

Class Instance Variables:
	uniqueInstance	<ProtoObject>!

RPSS_UserCollection class
	instanceVariableNames: 'uniqueInstance'!

!RPSS_UserCollection class methodsFor: 'as yet unclassified' stamp: 'BogatchevOleg 10/11/2011 23:13'!
reset
	uniqueInstance := nil.! !

!RPSS_UserCollection class methodsFor: 'as yet unclassified' stamp: 'BogatchevOleg 10/11/2011 23:13'!
uniqueInstance 
	uniqueInstance ifNil: [uniqueInstance := self new].
	^uniqueInstance! !

!RPSS_UserCollection methodsFor: 'traits' stamp: 'BogatchevOleg 10/12/2011 01:55'!
addUser: aUser
	collection at: (((aUser email) onlyLetters ) asSymbol ) put: aUser.! !

!RPSS_UserCollection methodsFor: 'accessing' stamp: 'BogatchevOleg 10/12/2011 00:55'!
collection
	^collection.! !

!RPSS_UserCollection methodsFor: 'initialization' stamp: 'BogatchevOleg 10/12/2011 00:36'!
initialize 
	super initialize.
	collection := IdentityDictionary new.! !

!RPSS_UserCollection methodsFor: 'select' stamp: 'BogatchevOleg 10/12/2011 18:20'!
usersToApprove
"select users that need approval"
	^ collection select: [ :user | user isToVerify & user emailVerified ]! !

WAComponent subclass: #RPSS_Administrator
	instanceVariableNames: 'email password initialized modified waiting url tempEmail tempPassword notify'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RPSS'!

RPSS_Administrator class
	instanceVariableNames: 'uniqueInstance'!

!RPSS_Administrator commentStamp: 'BogatchevOleg 10/12/2011 17:36' prior: 0!
I'm an RPSS Administrator, I can change my password, accept or deny new users. I am alone of my kind(singleton).

Instance Variables:
	email	<String>
	password	<String>
	initialized	<Boolean>
	modified	<ProtoObject | PseudoContext>
	waiting	<Boolean>
	url	<HTTPHeaders | WAUrl>
	tempEmail	<String>
	tempPassword	<String>
	notify	<Boolean>

Class Instance Variables:
	uniqueInstance	<ProtoObject>!

RPSS_Administrator class
	instanceVariableNames: 'uniqueInstance'!

!RPSS_Administrator class methodsFor: 'as yet unclassified' stamp: 'BogatchevOleg 10/10/2011 22:11'!
reset
	uniqueInstance := nil.! !

!RPSS_Administrator class methodsFor: 'as yet unclassified' stamp: 'BogatchevOleg 10/10/2011 22:11'!
uniqueInstance 
	uniqueInstance ifNil: [uniqueInstance := self new].
	^uniqueInstance! !

!RPSS_Administrator methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:37'!
activateWaiting
	"switching to waiting mode"
	waiting := true.! !

!RPSS_Administrator methodsFor: 'services' stamp: 'BogatchevOleg 10/12/2011 17:37'!
approve: anEmail
"approving a user"
	|msg to from subject body bodyhtml content collection user|
	collection := RPSS_UserCollection uniqueInstance collection.
	user := collection at: (anEmail onlyLetters) asSymbol.
	user isToVerify: false.
		

	to := MIMEHeaderValue forField: 'to' fromString: anEmail.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Registration successful'.
	
	bodyhtml := 'You are registered!! '.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.! !

!RPSS_Administrator methodsFor: 'actions' stamp: 'BogatchevOleg 10/11/2011 20:22'!
confirmEmail
	email := tempEmail.
	tempEmail := ''.! !

!RPSS_Administrator methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:38'!
confirmFirstEmail
"final initialization of administrator"
	waiting := false.
	initialized := true.! !

!RPSS_Administrator methodsFor: 'actions' stamp: 'BogatchevOleg 10/11/2011 20:10'!
confirmPassword
	password := tempPassword.
	tempPassword := ''.! !

!RPSS_Administrator methodsFor: 'services' stamp: 'BogatchevOleg 10/12/2011 17:38'!
deny: anEmail
"deny a user"
	|collection msg to from subject body bodyhtml content |
	collection := RPSS_UserCollection uniqueInstance collection.
	collection removeKey: ((anEmail onlyLetters ) asSymbol ).
	

	to := MIMEHeaderValue forField: 'to' fromString: anEmail.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Request denied'.
	
	bodyhtml := 'Your registration has been denied!!: '.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:28'!
email
	^email.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:28'!
email: anEmail
	email := anEmail.! !

!RPSS_Administrator methodsFor: 'initialization' stamp: 'BogatchevOleg 10/12/2011 00:05'!
initialize
	super initialize.
	email := ''.
	password := ''.
	initialized := false.
	waiting := false.
	url := ''.
	notify := true.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:23'!
isInitialized
	^initialized.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:23'!
isWaiting
	^waiting.! !

!RPSS_Administrator methodsFor: 'services' stamp: 'BogatchevOleg 10/12/2011 17:39'!
modifyEmail
"changing administrators email"
	|msg to from subject body bodyhtml link content|
	to := MIMEHeaderValue forField: 'to' fromString: tempEmail.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Password confirmation'.
	
	link := 'http://localhost:8080', url greaseString.
	bodyhtml := 'You can confirm your new email via this link: ', link.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.! !

!RPSS_Administrator methodsFor: 'services' stamp: 'BogatchevOleg 10/12/2011 17:39'!
modifyPassword
"changing administrators password" 
	|msg to from subject body bodyhtml link content|
	to := MIMEHeaderValue forField: 'to' fromString: self email.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Password confirmation'.
	
	link := 'http://localhost:8080', url greaseString.
	bodyhtml := 'You can confirm your new password via this link: ', link.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/12/2011 00:15'!
notify
	^notify.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/12/2011 00:05'!
notify: value
	notify := value.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:28'!
password
	^password.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:28'!
password: aPassword
	password := aPassword.! !

!RPSS_Administrator methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:40'!
save
"creation of administrator"
	|msg to from subject body bodyhtml link content|
	self verifyPassword & self verifyEmail 
	ifTrue:
	[
		self waiting
		ifTrue:
		[
			to := MIMEHeaderValue forField: 'to' fromString: self email.
			from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
			content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
			subject := MIMEHeaderValue fromTraditionalHeader:  'Email confirmation'.
	
			link := 'http://localhost:8080', url greaseString.
			bodyhtml := 'You can confirm your email via this link: ', link.
			body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
			msg := (MailMessage new setField: 'to' to: to;
			setField: 'from' to: from;
			setField: 'subject' to: subject;
			setField: 'content' to: content;
			body: body yourself).
			(MailComposition new sendMailMessage: msg) submit.
			self activateWaiting.
		]
		ifFalse:
		[
			initialized := true.
		]
	]
	ifFalse:
	[
		email := ''.
		password := ''.
	]! !

!RPSS_Administrator methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:40'!
setUrl: html action: anAction
"get the callback url depending on what we want to do"
	url := html actionUrl copy.
	anAction = 'initialize'
	ifTrue: 
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmFirstEmail ])).
	].
	anAction = 'email'
	ifTrue: 
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmEmail ])).
	].
	anAction = 'password'
	ifTrue: 
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmPassword])).
	].! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 19:52'!
tempEmail: aTempEmail
	tempEmail := aTempEmail.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 19:52'!
tempPassword: aTempPassword
	tempPassword := aTempPassword.! !

!RPSS_Administrator methodsFor: 'verifying' stamp: 'BogatchevOleg 10/10/2011 22:36'!
verifyEmail
	^true.! !

!RPSS_Administrator methodsFor: 'verifying' stamp: 'BogatchevOleg 10/10/2011 22:36'!
verifyPassword
	^true.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:30'!
waiting
	^waiting.! !

!RPSS_Administrator methodsFor: 'accessing' stamp: 'BogatchevOleg 10/10/2011 22:30'!
waiting: value
	waiting := value.! !

WAComponent subclass: #RPSS_Guest
	instanceVariableNames: 'password email verified tempEmail tempPassword url'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RPSS'!

!RPSS_Guest commentStamp: 'BogatchevOleg 10/12/2011 17:44' prior: 0!
I'm RPSS Guest, I represent a user browsing the application, and stock his data

Instance Variables:
	password	<String>
	email	<String>
	verified	<Boolean>
	tempEmail	<ProtoObject | PseudoContext>
	tempPassword	<String>
	url	<HTTPHeaders | WAUrl>!

!RPSS_Guest methodsFor: 'actions' stamp: 'BogatchevOleg 10/11/2011 19:21'!
confirmEmail
	email := tempEmail.
	verified := false.! !

!RPSS_Guest methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:41'!
confirmPassword 
"changing users password"
	|collection|
	password := tempPassword.
	tempPassword := ''.
	verified := false.
	collection := RPSS_UserCollection uniqueInstance collection.
	(collection at: (email onlyLetters ) asSymbol) password: password.
	! !

!RPSS_Guest methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 18:24'!
email
	^email.! !

!RPSS_Guest methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 18:25'!
email: anEmail
	email := anEmail.! !

!RPSS_Guest methodsFor: 'initialization' stamp: 'BogatchevOleg 10/11/2011 18:35'!
initialize 
	super initialize.
	email := ''.
	password := ''.
	verified := false.! !

!RPSS_Guest methodsFor: 'services' stamp: 'BogatchevOleg 10/12/2011 17:42'!
login
"login verifications"
	|administrator collection user|
	administrator := RPSS_Administrator uniqueInstance.
	(self email = administrator email) & (self password = administrator password)
	ifTrue:
	[
		verified := true.
	]
	ifFalse:
	[
		collection := RPSS_UserCollection uniqueInstance collection.
		(collection includesKey: (email onlyLetters) asSymbol)
		ifTrue:
		[
			user := collection at: (email onlyLetters) asSymbol.
			user password = password
			ifTrue:
			[
				verified := user isToVerify not.
			]
		] 
	].
! !

!RPSS_Guest methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:42'!
modifyEmail
"modifting users email"
|msg to from subject body bodyhtml link content|
	to := MIMEHeaderValue forField: 'to' fromString: tempEmail.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Password confirmation'.
	
	link := 'http://localhost:8080', url greaseString.
	bodyhtml := 'You can confirm your new mail via this link: ', link.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.! !

!RPSS_Guest methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:43'!
modifyPassword
"modifying users password"
|msg to from subject body bodyhtml link content|
	to := MIMEHeaderValue forField: 'to' fromString: self email.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Password confirmation'.
	
	link := 'http://localhost:8080', url greaseString.
	bodyhtml := 'You can confirm your new password via this link: ', link.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.! !

!RPSS_Guest methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 18:25'!
password
	^password.! !

!RPSS_Guest methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 18:25'!
password: aPassword
	password := aPassword.! !

!RPSS_Guest methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:43'!
setUrl: html action: anAction
"getting callback url depending on desired action"
	url := html actionUrl copy.
	anAction = 'email'
	ifTrue:
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmEmail ])).
	].

	anAction = 'password'
	ifTrue:
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmPassword ])).
	].
! !

!RPSS_Guest methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 19:06'!
tempEmail: aTempEmail
	tempEmail := aTempEmail.! !

!RPSS_Guest methodsFor: 'accessing' stamp: 'BogatchevOleg 10/12/2011 03:32'!
tempPassword: aTempPassword
	tempPassword := aTempPassword.! !

!RPSS_Guest methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 18:36'!
verified
	^verified.! !

WAComponent subclass: #RPSS_Main
	instanceVariableNames: 'administrator guest userCreation userCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RPSS'!

!RPSS_Main commentStamp: 'BogatchevOleg 10/12/2011 17:44' prior: 0!
I'm RPSS Main, I take care of global rendering

Instance Variables:
	administrator	<RPSS_Administrator>
	guest	<RPSS_Guest>
	userCreation	<RPSS_User>
	userCollection	<RPSS_UserCollection>!

!RPSS_Main class methodsFor: 'as yet unclassified' stamp: 'TimLenertz 10/12/2011 05:01'!
canBeRoot 
	^true.! !

!RPSS_Main methodsFor: 'hooks' stamp: 'BogatchevOleg 10/11/2011 21:21'!
children 
	^Array with: userCreation.! !

!RPSS_Main methodsFor: 'initialization' stamp: 'BogatchevOleg 10/11/2011 23:14'!
initialize 
	super initialize.
	administrator := RPSS_Administrator uniqueInstance.
	guest := RPSS_Guest new.
	userCreation := RPSS_User new.
	userCollection := RPSS_UserCollection uniqueInstance.! !

!RPSS_Main methodsFor: 'rendering' stamp: 'BogatchevOleg 10/12/2011 07:13'!
renderAdministrator: html
	html paragraph: 'Welcome administrator'.
	
	html paragraph: 'You can modify your email:'.
	html form: 
	[
		html textInput callback: [:value | administrator tempEmail: value].
		html break.
		html submitButton callback: [administrator setUrl: html action: 'email'. administrator modifyEmail]; value: 'Modify!!'.
	].

	html paragraph: 'You can modify your password:'.
	html form:
	[
		html textInput callback: [:value | administrator tempPassword: value].
		html break.
		html submitButton callback: [administrator setUrl: html action: 'password'. administrator modifyPassword]; value: 'Modify!!'.
	].

	html paragraph: 'New users waiting to be approved:'.
	RPSS_UserCollection uniqueInstance usersToApprove do: [ :user |
		html form: [
			html text: user email.
			html submitButton value: 'Approve'; callback: [ administrator approve: user email ].
			html submitButton value: 'Deny'; callback: [ administrator deny: user email ].
			html break.
		]
	]! !

!RPSS_Main methodsFor: 'rendering' stamp: 'BogatchevOleg 10/11/2011 19:47'!
renderContentOn: html
	administrator isInitialized
	ifFalse: 
	[
		administrator isWaiting
		ifFalse: 
		[
			self renderInitialization: html.
		]
		ifTrue: 
		[
			self renderWaiting: html.
		]
		
	]
	ifTrue:
	[
		guest verified
		ifFalse: 
		[	
			self renderGuest: html.
			
		]
		ifTrue:
		[
			guest email = administrator email
			ifTrue: 
			[
				self renderAdministrator: html.
			]
			ifFalse: 
			[
				self renderUser: html.
			].
		]
	]! !

!RPSS_Main methodsFor: 'rendering' stamp: 'BogatchevOleg 10/11/2011 22:33'!
renderCreateUser: html
	self call: userCreation.! !

!RPSS_Main methodsFor: 'rendering' stamp: 'BogatchevOleg 10/11/2011 23:14'!
renderGuest: html
	html paragraph: 'Welcome to the main page'.
	html paragraph: 'To login, please provide the following information'.
	html 	form: 
			[
				html 	paragraph: 'Your e-mail adress:'.
				html 	textInput callback: [:value | guest email: value].
				html 	paragraph: 'Your password:'.
				html 	textInput type: 'password'; callback: [:value | guest password: value].
				html 	break.
				html 	submitButton callback: [ guest login]; value: 'Login!!'.
			].
	html paragraph: [html anchor callback: [self renderCreateUser: html]; with: 'Create a new user'.].! !

!RPSS_Main methodsFor: 'rendering' stamp: 'BogatchevOleg 10/12/2011 00:10'!
renderInitialization: html
	html div id: 'testId'; class: 'testClass'; with: 
	[
		html	paragraph: 'Welcome to A general purpose web based virtual tabletop'.
		html	paragraph: 'This version is done by group 9'.
		html 	break; break.
		html 	paragraph: 'The system is not yet initialized, please provide the following information:'.
		html 	form: 
			[
				html 	paragraph: 'Your e-mail adress:'.
				html 	textInput callback: [:value | administrator email: value].
				html 	paragraph: 'Your password:'.
				html 	textInput type: 'password'; callback: [:value | administrator password: value].
				html 	break.
				html 	paragraph: 'Email confirmation'. 
				html 	checkbox value: true; callback: [ :value | administrator waiting: value].
				html 	break.
				html 	paragraph: 'Email confirmation of every new user'. 
				html 	checkbox value: true; callback: [ :value | administrator notify: value].
				html 	break.
				html 	submitButton callback: [ administrator setUrl: html action: 'initialize'. administrator save]; value: 'Initialize!!'.
			].
	]! !

!RPSS_Main methodsFor: 'rendering' stamp: 'BogatchevOleg 10/12/2011 02:48'!
renderUser: html
	html paragraph: 'You are logged in!!'.
	html paragraph: 'You can modify your email:'.
	html form: 
	[
		html textInput callback: [:value | guest tempEmail: value].
		html break.
		html submitButton callback: [guest setUrl: html action:'email'. guest modifyEmail]; value: 'Modify!!'.
	].
	html paragraph: 'You can modify your password:'.
	html form:
	[
		html textInput type: 'password'; callback: [:value | guest tempPassword: value].
		html break.
		html submitButton callback: [guest setUrl: html action: 'password '. guest modifyPassword]; value: 'Modify!!'.
	].! !

!RPSS_Main methodsFor: 'rendering' stamp: 'BogatchevOleg 10/10/2011 22:37'!
renderWaiting: html
	html paragraph: 'Waiting for email confirmation'.! !

!RPSS_Main methodsFor: 'rendering' stamp: 'TimLenertz 10/12/2011 05:07'!
style 
	^ 'body{text-align:center;}'! !

WAComponent subclass: #RPSS_User
	instanceVariableNames: 'email password url tempEmail tempPassword isToVerify emailVerified urlVerify urlDeny'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RPSS'!

!RPSS_User commentStamp: 'BogatchevOleg 10/12/2011 17:53' prior: 0!
I'm RPSS userCreator, my task is to create a new user

Instance Variables:
	email	<String>
	password	<String>
	url	<HTTPHeaders | WAUrl>
	tempEmail	<String>
	tempPassword	<String>
	isToVerify	<Boolean>
	emailVerified	<Boolean>
	urlVerify	<HTTPHeaders | WAUrl>
	urlDeny	<HTTPHeaders | WAUrl>!

!RPSS_User methodsFor: 'actions' stamp: 'BogatchevOleg 10/11/2011 22:43'!
confirmEmail
	email := tempEmail.
	tempEmail := ''.! !

!RPSS_User methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:54'!
confirmFirstEmail
"validate my email"
	|msg to from subject body bodyhtml link link2 content administrator|
	emailVerified := true.
		
	administrator := RPSS_Administrator uniqueInstance.
	administrator notify
	ifTrue: 
	[
		to := MIMEHeaderValue forField: 'to' fromString: administrator email.
		from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
		content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
		subject := MIMEHeaderValue fromTraditionalHeader:  'New user'.
		
		link := 'http://localhost:8080', urlVerify greaseString.
		link2 := 'http://localhost:8080', urlDeny greaseString.
		bodyhtml := 'A new user created an account, please validate him, his email: ', email, ' to validate ',link, ' to reject ',link2.
		body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
		msg := (MailMessage new setField: 'to' to: to;
		setField: 'from' to: from;
		setField: 'subject' to: subject;
		setField: 'content' to: content;
		body: body yourself).
		(MailComposition new sendMailMessage: msg) submit.
	].! !

!RPSS_User methodsFor: 'actions' stamp: 'BogatchevOleg 10/11/2011 22:43'!
confirmPassword
	password := tempPassword.
	tempPassword := ''.! !

!RPSS_User methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:54'!
denyUser
"deny this user"
	|collection msg to from subject body bodyhtml content |
	collection := RPSS_UserCollection uniqueInstance.
	collection collection removeKey: ((email onlyLetters ) asSymbol ).
	
	

	to := MIMEHeaderValue forField: 'to' fromString: self email.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Request denied'.
	
	bodyhtml := 'Your registration has been denied!!: '.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.! !

!RPSS_User methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 22:40'!
email
	^email.! !

!RPSS_User methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 22:40'!
email: anEmail
	email := anEmail.! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
emailVerified
	^ emailVerified! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
emailVerified: anObject
	emailVerified := anObject! !

!RPSS_User methodsFor: 'initialization' stamp: 'BogatchevOleg 10/12/2011 02:15'!
initialize
	super initialize.
	url := ''.
	email := ''.
	password := ''.
	isToVerify := true.
	emailVerified := false.
	urlVerify := ''.
	urlDeny := ''.! !

!RPSS_User methodsFor: 'accessing' stamp: 'BogatchevOleg 10/12/2011 02:03'!
isToVerify
	^isToVerify.! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:16'!
isToVerify: anObject
	isToVerify := anObject! !

!RPSS_User methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 22:40'!
password
	^password.! !

!RPSS_User methodsFor: 'accessing' stamp: 'BogatchevOleg 10/11/2011 22:40'!
password: aPassword
	password := aPassword.! !

!RPSS_User methodsFor: 'rendering' stamp: 'BogatchevOleg 10/12/2011 02:31'!
renderContentOn: html
	email = ''
	ifTrue: [
		self setUrl: html action: 'denyUser'.
		self setUrl: html action: 'verifyUser'.
		html paragraph: 'A demand will be sent with the following data to the administrator:'.
		html 	form: 
		[
			html 	paragraph: 'Your e-mail adress:'.
			html 	textInput callback: [:value | self email: value].
			html 	paragraph: 'Your password:'.
			html 	textInput type: 'password'; callback: [:value | self password: value].
			html 	break.
			html 	submitButton callback: [ self setUrl: html action: 'initialize'. self save]; value: 'Send!!'.
		].
	]
	ifFalse: 
	[
		emailVerified 
		ifFalse: 
		[
			html paragraph: 'Please validate your email to procced'.
		]
		ifTrue: 
		[
			html paragraph: 'Your mail is validated, wait for the administrator to accept you'.
		]
	]! !

!RPSS_User methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:55'!
save
"save the input data and create a new user"
	|msg to from subject body bodyhtml link content collection|

	to := MIMEHeaderValue forField: 'to' fromString: self email.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Email confirmation'.
	
	link := 'http://localhost:8080', url greaseString.
	bodyhtml := 'You can confirm your email via this link: ', link.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.
	
	collection := RPSS_UserCollection uniqueInstance.
	collection addUser: self.

	
	! !

!RPSS_User methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:55'!
setUrl: html action: anAction
"save callback actions depending on the action"
	url := html actionUrl copy.
	anAction = 'initialize'
	ifTrue: 
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmFirstEmail ])).
	].
	anAction = 'email'
	ifTrue: 
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmEmail ])).
	].
	anAction = 'password'
	ifTrue: 
	[
		url addField: (html callbacks store: (WAActionCallback on: [ self confirmPassword])).
	].
	anAction = 'verifyUser'
	ifTrue: 
	[
		urlVerify := html actionUrl copy.
		urlVerify addField: (html callbacks store: (WAActionCallback on: [ self verifyUser])).
	].
	anAction = 'denyUser'
	ifTrue: 
	[
		urlDeny := html actionUrl copy.
		urlDeny addField: (html callbacks store: (WAActionCallback on: [ self denyUser])).
	].! !

!RPSS_User methodsFor: 'hooks' stamp: 'BogatchevOleg 10/11/2011 22:34'!
style 
	^ 'p{text-align:center;}
	form{text-align:center;}'! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:16'!
tempEmail
	^ tempEmail! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:16'!
tempEmail: anObject
	tempEmail := anObject! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:16'!
tempPassword
	^ tempPassword! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:16'!
tempPassword: anObject
	tempPassword := anObject! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
url
	^ url! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
url: anObject
	url := anObject! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
urlDeny
	^ urlDeny! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
urlDeny: anObject
	urlDeny := anObject! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
urlVerify
	^ urlVerify! !

!RPSS_User methodsFor: 'accessing' stamp: 'TimLenertz 10/12/2011 05:15'!
urlVerify: anObject
	urlVerify := anObject! !

!RPSS_User methodsFor: 'actions' stamp: 'BogatchevOleg 10/12/2011 17:55'!
verifyUser
"validate user"
|msg to from subject body bodyhtml content collection|
	isToVerify := false.
		

	to := MIMEHeaderValue forField: 'to' fromString: self email.
	from := MIMEHeaderValue forField: 'from' fromString: 'admin@ulb.ac.be'.
	content := MIMEHeaderValue forField: 'content' fromString: 'text/html'.
	subject := MIMEHeaderValue fromTraditionalHeader:  'Registration successful'.
	
	bodyhtml := 'You are registered!! '.
	body := MIMEDocument contentType: 'text/html' content: bodyhtml.
	
	msg := (MailMessage new setField: 'to' to: to;
	setField: 'from' to: from;
	setField: 'subject' to: subject;
	setField: 'content' to: content;
	body: body yourself).
	(MailComposition new sendMailMessage: msg) submit.
	self answer.! !
